{% extends "datawok/base.html" %}
{% load static %}

{% block headscripts %}
  {{ block.super }}
  <script type="text/javascript" src="{% static 'datawok/js/papaparse.min.js' %}"></script>
{% endblock %}

{% block api %}
  {{ block.super }}

  <meta name="MODEL" content="{{ model }}">
  <meta name="METAPK" content="{{ meta_pk }}">
  <meta name="QUERY_LIMIT" content="{{ query_limit }}">
<!-- end -->

{% endblock %}

{% block styles %}
  {{ block.super }}

  <link rel="stylesheet" href="{% static 'datawok/css/main.detail.css' %}">
{% endblock %}

{% block data %}
  <script>
    window.FIELDS = JSON.parse({{ fields | safe }});
    window.QUERIES = JSON.parse({{ queries | safe }});
  </script>
{% endblock %}

{% block app %}
<script type="text/javascript" src="{% static 'datawok/js/main.detail.js' %}"></script>
{% endblock %}
