{% extends "datawok/base.html" %}
{% load static %}

{% block styles %}
  {{ block.super }}

  <link rel="stylesheet" href="{% static 'datawok/css/main.list.css' %}">
{% endblock %}

{% block app %}
<script type="text/javascript" src="{% static 'datawok/js/main.list.js' %}"></script>
{% endblock %}
