<!DOCTYPE html>
<html>
  <head>
    <meta charset="utf-8">
    <title></title>
  </head>
  <body>
    <img src="https://rawgithub.com/The-Politico/src/master/images/logo/badge.png" />
    <h1 style="margin-top:0px;">Hello, mother!</h1>

    <iframe width="560" height="315" src="https://www.youtube.com/embed/V7uEb_XrK1U?rel=0&amp;showinfo=0&amp;autoplay=1" frameborder="0" gesture="media" allow="encrypted-media" allowfullscreen></iframe>

    <!-- Use me to authenticate basic AJAX requests -->
    <input  type="hidden" value="{{secret}}" />
  </body>
</html>
